unit Unit1;

interface

uses
  Winapi.Windows, Winapi.Messages, System.SysUtils, System.Variants, System.Classes, Vcl.Graphics,
  Vcl.Controls, Vcl.Forms, Vcl.Dialogs, VclTee.TeeGDIPlus, Vcl.StdCtrls,
  Vcl.ExtCtrls, VCLTee.TeEngine, VCLTee.TeeProcs, VCLTee.Chart, VCLTee.Series,
  VCLTee.TeeTools, VCLTee.imapoint, Vcl.Samples.Spin;

type
  TForm1 = class(TForm)
    Chart1: TChart;
    Panel1: TPanel;
    btnReload: TButton;
    Series1: TBarSeries;
    ChartTool1: TRectangleTool;
    spnNumValues: TSpinEdit;
    spnIconValue: TSpinEdit;
    Label1: TLabel;
    Label2: TLabel;
    procedure btnReloadClick(Sender: TObject);
    procedure Chart1MouseMove(Sender: TObject; Shift: TShiftState; X, Y: Integer);
    procedure spnIconValueChange(Sender: TObject);
    procedure spnNumValuesChange(Sender: TObject);
  private
    { Private declarations }
    FsrsPoint: TImagePointSeries;
    procedure LoadSeries;
    procedure UpdateSeriesIcon;
  public
    { Public declarations }
    constructor Create(aOwner: TComponent); override;
  end;

var
  Form1: TForm1;

implementation

uses
  Vcl.Imaging.pngimage, System.Math;

{$R *.dfm}

procedure TForm1.btnReloadClick(Sender: TObject);
begin
  LoadSeries;
end;

procedure TForm1.Chart1MouseMove(Sender: TObject; Shift: TShiftState; X, Y:
    Integer);
begin
  FsrsPoint.Marks.Visible:= FsrsPoint.Clicked(X,Y)>-1;
end;

constructor TForm1.Create(aOwner: TComponent);
begin
  inherited;
  FsrsPoint := nil;
  LoadSeries;
end;

procedure TForm1.LoadSeries;
var i: Integer;
  lNumValues: Integer;
begin
  Chart1.FreeAllSeries;
  FsrsPoint := nil;

  lNumValues := spnNumValues.Value;
  for i:=0 to 4 do
    with Chart1.AddSeries(TBarSeries) as TBarSeries do begin
      FillSampleValues(lNumValues);
      MultiBar:=mbStacked;
      Marks.Visible:=False;
    end;

  UpdateSeriesIcon;

  Chart1.Axes.Bottom.LabelStyle:=talValue;
end;

procedure TForm1.spnIconValueChange(Sender: TObject);
begin
  UpdateSeriesIcon;
end;

procedure TForm1.spnNumValuesChange(Sender: TObject);
begin
  LoadSeries;
end;

procedure TForm1.UpdateSeriesIcon;
var
  lNumValues: Integer;
  lIconValue: Integer;
  lFileName: string;
  lValue: double;
  I: integer;
begin
  if assigned(FsrsPoint) then
    FreeAndNil(FsrsPoint);

  lNumValues := spnNumValues.Value;
  lIconValue := spnIconValue.Value;

  if InRange(lIconValue, 1, lNumValues) then begin
    dec(lIconValue);

    FsrsPoint := Chart1.AddSeries(TImagePointSeries) as TImagePointSeries;
    with FsrsPoint do begin
      Title:='Event explanation';
      Pointer.Size:=24;
      lFileName := ExtractFilePath(ParamStr(0)) + 'Recycle.png';
      Pointer.Picture.LoadFromFile(lFileName);
      Pointer.InflateMargins:=False;

      lValue :=0;
      for i:=0 to Chart1.SeriesCount-1 do
        if Chart1[i] is TBarSeries then
           lValue:=lValue+Chart1[i].YValue[lIconValue];

      Chart1.Draw;

      with Chart1.Axes.Left do
        lValue:=CalcPosPoint(CalcPosValue(lValue) - Pointer.Size);

      AddXY(lIconValue, lValue, Title);
      Marks.Transparent:=True;
    end;
  end;
end;

end.
